Install — django-markdowny 0.1 documentation

# Install

Install with the pip package manager.

    $ mkvirtualenv myvenv -p python3
    $ pip install django
    $ pip install django-markdowny

After creating a project, add `markdowny` to `INSTALLED_APPS` in `settings.py`.

    INSTALLED_APPS = [
        # ...
        'markdowny',
    ]

Remember to update your `requirements.txt` file. In your project directory:

    $ pip freeze > requirements.txt